@@ -15,12 +15,12 @@
 import bisect
 import hashlib
 import struct
-import uuid
 
 from oslo_config import cfg
 from oslo_log import log
-import retrying
+from oslo_utils import uuidutils
 import six
+import tenacity
 import tooz.coordination
 
 from aodh.i18n import _LE, _LI, _LW
@@ -62,19 +62,11 @@ class ErrorJoiningPartitioningGroup(Exception):
 class MemberNotInGroupError(Exception):
     def __init__(self, group_id, members, my_id):
         super(MemberNotInGroupError, self).__init__(_LE(
-            'Group ID: %{group_id}s, Members: %{members}s, Me: %{me}s: '
+            'Group ID: %(group_id)s, Members: %(members)s, Me: %(me)s: '
             'Current agent is not part of group and cannot take tasks') %
             {'group_id': group_id, 'members': members, 'me': my_id})
 
 
-def retry_on_error_joining_partition(exception):
-    return isinstance(exception, ErrorJoiningPartitioningGroup)
-
-
-def retry_on_member_not_in_group(exception):
-    return isinstance(exception, MemberNotInGroupError)
-
-
 class HashRing(object):
 
     def __init__(self, nodes, replicas=100):
@@ -124,7 +116,7 @@ class PartitionCoordinator(object):
         self.backend_url = self.conf.coordination.backend_url
         self._coordinator = None
         self._groups = set()
-        self._my_id = my_id or str(uuid.uuid4())
+        self._my_id = my_id or uuidutils.generate_uuid()
 
     def start(self):
         if self.backend_url:
@@ -164,28 +156,17 @@ class PartitionCoordinator(object):
                 LOG.exception(_LE('Error sending a heartbeat to coordination '
                                   'backend.'))
 
-    def watch_group(self, namespace, callback):
-        if self._coordinator:
-            self._coordinator.watch_join_group(namespace, callback)
-            self._coordinator.watch_leave_group(namespace, callback)
-
-    def run_watchers(self):
-        if self._coordinator:
-            self._coordinator.run_watchers()
-
     def join_group(self, group_id):
         if (not self._coordinator or not self._coordinator.is_started
                 or not group_id):
             return
 
-        retry_backoff = self.conf.coordination.retry_backoff * 1000
-        max_retry_interval = self.conf.coordination.max_retry_interval * 1000
-
-        @retrying.retry(
-            wait_exponential_multiplier=retry_backoff,
-            wait_exponential_max=max_retry_interval,
-            retry_on_exception=retry_on_error_joining_partition,
-            wrap_exception=True)
+        @tenacity.retry(
+            wait=tenacity.wait_exponential(
+                multiplier=self.conf.coordination.retry_backoff,
+                max=self.conf.coordination.max_retry_interval),
+            retry=tenacity.retry_if_exception_type(
+                ErrorJoiningPartitioningGroup))
         def _inner():
             try:
                 join_req = self._coordinator.join_group(group_id)
@@ -227,8 +208,11 @@ class PartitionCoordinator(object):
             except tooz.coordination.GroupNotCreated:
                 self.join_group(group_id)
 
-    @retrying.retry(stop_max_attempt_number=5, wait_random_max=2000,
-                    retry_on_exception=retry_on_member_not_in_group)
+    @tenacity.retry(
+        wait=tenacity.wait_random(max=2),
+        stop=tenacity.stop_after_attempt(5),
+        retry=tenacity.retry_if_exception_type(MemberNotInGroupError),
+        reraise=True)
     def extract_my_subset(self, group_id, universal_set):
         """Filters an iterable, returning only objects assigned to this agent.
 
